==> zio-aws-sesv2_3-5.17.128.1-sources.jar: zio/aws/sesv2/model/UpdateContactListRequest.scala <==
package zio.aws.sesv2.model
import zio.aws.sesv2.model.primitives.{Description, ContactListName}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class UpdateContactListRequest(
    contactListName: ContactListName,
    topics: Option[Iterable[zio.aws.sesv2.model.Topic]] = None,
    description: Option[Description] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sesv2.model.UpdateContactListRequest = {
    import UpdateContactListRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sesv2.model.UpdateContactListRequest
      .builder()
      .contactListName(
        ContactListName.unwrap(contactListName): java.lang.String
      )
      .optionallyWith(
        topics.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.topics)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .build()
  }
  def asReadOnly: zio.aws.sesv2.model.UpdateContactListRequest.ReadOnly =
    zio.aws.sesv2.model.UpdateContactListRequest.wrap(buildAwsValue())
}
object UpdateContactListRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sesv2.model.UpdateContactListRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sesv2.model.UpdateContactListRequest =
      zio.aws.sesv2.model.UpdateContactListRequest(
        contactListName,
        topics.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        description.map(value => value)
      )
    def contactListName: ContactListName
    def topics: Option[List[zio.aws.sesv2.model.Topic.ReadOnly]]
    def description: Option[Description]
    def getContactListName: ZIO[Any, Nothing, ContactListName] =
      ZIO.succeed(contactListName)
    def getTopics
        : ZIO[Any, AwsError, List[zio.aws.sesv2.model.Topic.ReadOnly]] =
      AwsError.unwrapOptionField("topics", topics)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sesv2.model.UpdateContactListRequest
  ) extends zio.aws.sesv2.model.UpdateContactListRequest.ReadOnly {
    override val contactListName: ContactListName =
      zio.aws.sesv2.model.primitives.ContactListName(impl.contactListName())
    override val topics: Option[List[zio.aws.sesv2.model.Topic.ReadOnly]] =
      scala
        .Option(impl.topics())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sesv2.model.Topic.wrap(item)
          }.toList
        )
    override val description: Option[Description] = scala
      .Option(impl.description())
      .map(value => zio.aws.sesv2.model.primitives.Description(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sesv2.model.UpdateContactListRequest
  ): zio.aws.sesv2.model.UpdateContactListRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-sesv2_3-6.20.78.1-sources.jar: zio/aws/sesv2/model/UpdateContactListRequest.scala <==
package zio.aws.sesv2.model
import zio.aws.sesv2.model.primitives.{Description, ContactListName}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class UpdateContactListRequest(
    contactListName: ContactListName,
    topics: Optional[Iterable[zio.aws.sesv2.model.Topic]] = Optional.Absent,
    description: Optional[Description] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sesv2.model.UpdateContactListRequest = {
    import UpdateContactListRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sesv2.model.UpdateContactListRequest
      .builder()
      .contactListName(
        ContactListName.unwrap(contactListName): java.lang.String
      )
      .optionallyWith(
        topics.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.topics)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .build()
  }
  def asReadOnly: zio.aws.sesv2.model.UpdateContactListRequest.ReadOnly =
    zio.aws.sesv2.model.UpdateContactListRequest.wrap(buildAwsValue())
}
object UpdateContactListRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sesv2.model.UpdateContactListRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sesv2.model.UpdateContactListRequest =
      zio.aws.sesv2.model.UpdateContactListRequest(
        contactListName,
        topics.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        description.map(value => value)
      )
    def contactListName: ContactListName
    def topics: Optional[List[zio.aws.sesv2.model.Topic.ReadOnly]]
    def description: Optional[Description]
    def getContactListName: ZIO[Any, Nothing, ContactListName] =
      ZIO.succeed(contactListName)
    def getTopics
        : ZIO[Any, AwsError, List[zio.aws.sesv2.model.Topic.ReadOnly]] =
      AwsError.unwrapOptionField("topics", topics)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sesv2.model.UpdateContactListRequest
  ) extends zio.aws.sesv2.model.UpdateContactListRequest.ReadOnly {
    override val contactListName: ContactListName =
      zio.aws.sesv2.model.primitives.ContactListName(impl.contactListName())
    override val topics: Optional[List[zio.aws.sesv2.model.Topic.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.topics())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sesv2.model.Topic.wrap(item)
          }.toList
        )
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.sesv2.model.primitives.Description(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sesv2.model.UpdateContactListRequest
  ): zio.aws.sesv2.model.UpdateContactListRequest.ReadOnly = new Wrapper(impl)
}
